@@ -1,8 +1,7 @@
 #!/usr/bin/env bash
 # created by Tobias Powalowski <tpowa@archlinux.org>
-source /usr/lib/archboot/functions
-source /usr/lib/archboot/container_functions
-_CACHEDIR="${1}/var/cache/pacman/pkg"
+. /usr/lib/archboot/common.sh
+. /usr/lib/archboot/container.sh
 _ARCHBOOT="archboot"
 _KEYRING="archlinux"
 [[ -z "${1}" ]] && _usage
@@ -23,6 +22,7 @@ _clean_container "${1}"
 _clean_archboot_cache
 _generate_keyring "${1}" || exit 1
 _copy_mirrorlist_and_pacman_conf "${1}"
+_copy_archboot_defaults "${1}"
 _change_pacman_conf "${1}" || exit 1
 # enable [testing] if enabled in host
 if grep -q "^\[testing" /etc/pacman.conf; then
